@@ -8,7 +8,7 @@ use Scalar::Util ();
 
 with 'Bubblegum::Object::Role::Value';
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 
@@ -48,13 +48,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bubblegum::Object::Scalar - Common Methods for Operating on Scalars
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -65,7 +67,9 @@ version 0.10
 
 =head1 DESCRIPTION
 
-Scalar methods work on data that meets the criteria for being a defined.
+Scalar methods work on data that meets the criteria for being a defined. It is
+not necessary to use this module as it is loaded automatically by the
+L<Bubblegum> class.
 
 =head1 METHODS
 
