@@ -5,7 +5,7 @@ use Bubblegum::Class 'with';
 
 with 'Bubblegum::Object::Role::Item';
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 
@@ -19,13 +19,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bubblegum::Object::Undef - Common Methods for Operating on Undefined Values
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -37,7 +39,8 @@ version 0.10
 =head1 DESCRIPTION
 
 Undefined methods work on variables whose data meets the criteria for being
-undefined.
+undefined. It is not necessary to use this module as it is loaded automatically
+by the L<Bubblegum> class.
 
 =head1 METHODS
 
